<?php

namespace Bixo\Listing\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Bixo\Listing\Http\Requests\ReferralRequest;
use Bixo\Listing\Models\Referral;

/**
 * Admin web controller class.
 */
class ReferralWorkflowController extends BaseController
{

    /**
     * Workflow controller function for referral.
     *
     * @param Model   $referral
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ReferralRequest $request, Referral $referral, $step)
    {

        try {

            $referral->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('listing::referral.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/referral/referral/' . $referral->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/referral/referral/' . $referral->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for referral.
     *
     * @param Model   $referral
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Referral $referral, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $referral->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('listing::referral.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('listing::admin.referral.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('listing::admin.referral.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('listing::admin.referral.message', $data)->render();

        }

    }
}
