<?php

namespace Bixo\Listing\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Listing\Models\Referral;

class ReferralPolicy
{

    /**
     * Determine if the given user can view the referral.
     *
     * @param UserPolicy $user
     * @param Referral $referral
     *
     * @return bool
     */
    public function view(UserPolicy $user, Referral $referral)
    {
        if ($user->canDo('listing.referral.view') && $user->isAdmin()) {
            return true;
        }

        return $referral->user_id == user_id() && $referral->user_type == user_type();
    }

    /**
     * Determine if the given user can create a referral.
     *
     * @param UserPolicy $user
     * @param Referral $referral
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('listing.referral.create');
    }

    /**
     * Determine if the given user can update the given referral.
     *
     * @param UserPolicy $user
     * @param Referral $referral
     *
     * @return bool
     */
    public function update(UserPolicy $user, Referral $referral)
    {
        if ($user->canDo('listing.referral.edit') && $user->isAdmin()) {
            return true;
        }

        return $referral->user_id == user_id() && $referral->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given referral.
     *
     * @param UserPolicy $user
     * @param Referral $referral
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Referral $referral)
    {
        return $referral->user_id == user_id() && $referral->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given referral.
     *
     * @param UserPolicy $user
     * @param Referral $referral
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Referral $referral)
    {
        if ($user->canDo('listing.referral.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given referral.
     *
     * @param UserPolicy $user
     * @param Referral $referral
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Referral $referral)
    {
        if ($user->canDo('listing.referral.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
